# == Class: puppet_dev

class puppet_dev {
  $src_path = '/usr/local/src'
  $rvm_path = '/usr/local/rvm/bin/rvm'
  $ruby_version = '1.9.3'

  stage { ['epel', 'git', 'end']: }
  Stage['epel'] -> Stage['rvm-install'] -> Stage['git'] -> Stage['main'] -> Stage['end']

  if $::osfamily == 'RedHat' {
    class { 'epel':
      stage => epel,
    }
  }

  include rvm
  rvm_system_ruby { "ruby-${ruby_version}":
    ensure      => present,
    default_use => true,
  }

  class { 'git':
    stage => git,
  }

  ensure_resource('package', 'sqlite-devel', {'ensure' => 'installed'})

  git::repo { 'puppet':
    path   => "${src_path}/puppet",
    source => 'git://github.com/puppetlabs/puppet.git',
  }

  exec { 'Bundle puppet':
    command => "${rvm_path} ${ruby_version} do bundle",
    cwd     => "${src_path}/puppet/",
    creates => "${src_path}/puppet/Gemfile.lock",
    require => [Git::Repo['puppet'], Package['sqlite-devel']],
  }

  git::repo { 'puppetlabs-stdlib':
    path   => "${src_path}/puppetlabs-stdlib",
    source => 'git://github.com/puppetlabs/puppetlabs-stdlib.git',
  }

  exec { 'Bundle puppetlabs-stdlib':
    command => "${rvm_path} ${ruby_version} do bundle",
    cwd     => "${src_path}/puppetlabs-stdlib/",
    creates => "${src_path}/puppetlabs-stdlib/Gemfile.lock",
    require => Git::Repo['puppetlabs-stdlib'],
  }

  git::repo { 'puppetlabs-spec_helper':
    path   => "${src_path}/puppetlabs-spec_helper",
    source => 'git://github.com/puppetlabs/puppetlabs_spec_helper.git',
  }

  class { 'puppet_dev::end':
    stage => end,
  }

}

class puppet_dev::end {
  notify { 'end':
    message  => 'NOTE: Now run `source /usr/local/rvm/scripts/rvm` to load the RVM environment.',
    withpath => false,
  }
}